Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(415)

Unified Diff: test/test.sh

Issue 973433003: Initial cut for a development server (Closed) Base URL: git@github.com:dart-lang/dev_compiler.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/end_to_end_test.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/test.sh
diff --git a/test/test.sh b/test/test.sh
index f8d94ec2faf2f99b4d2199eb74958f15245eb338..30325fd94dbfa5eec03aaf98f29cc7fb0b788fb7 100755
--- a/test/test.sh
+++ b/test/test.sh
@@ -6,9 +6,12 @@ function fail {
return 1
}
-# Arguments passed to the diff tool. We exclude *.map files so they aren't
-# compared, as the diff is not human readable.
-DIFF_ARGS="-u -r -N --exclude=\*.map expect actual"
+# Arguments passed to the diff tool. We exclude:
+# - *.map files so they aren't compared, as the diff is not human readable.
+# - runtime JS files that are just copied over from the sources and are not
+# duplicated in the expected folder.
+DIFF_ARGS="-u -r -N --exclude=\*.map --exclude=dart_runtime.js \
+ --exclude=harmony_feature_check.js expect actual"
function show_diff {
echo "Fail: actual output did not match expected"
@@ -22,7 +25,7 @@ function show_diff {
fail
}
-# the directory of this script
+# the directory of this script
TEST_DIR=$( cd $( dirname "${BASH_SOURCE[0]}" ) && pwd )
# Some tests require being run from the package root
« no previous file with comments | « test/end_to_end_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698